Index: java/net/deterlab/abac/Context.java
===================================================================
--- java/net/deterlab/abac/Context.java	(revision a5cfe9380358e20820ab6e6ae7751995d5cad2a4)
+++ java/net/deterlab/abac/Context.java	(revision edf9e1d27f9b1cb99d21598d7ab39008a44fa72d)
@@ -114,7 +114,7 @@
 	this();
 	for (Identity i: c.identities) 
-	    loadIDChunk(i);
+	    load_id_chunk(i);
 	for (Credential cr: c.credentials()) 
-	    loadAttributeChunk(cr);
+	    load_attribute_chunk(cr);
 	derive_implied_edges();
     }
@@ -125,5 +125,5 @@
      * @return one of the static int return codes.
      */
-    public int loadIDFile(String fn) { return loadIDChunk(new File(fn)); }
+    public int load_id_file(String fn) { return load_id_chunk(new File(fn)); }
     /**
      * Load an Identity from a file.
@@ -131,5 +131,5 @@
      * @return one of the static int return codes.
      */
-    public int loadIDFile(File fn) { return loadIDChunk(fn); }
+    public int load_id_file(File fn) { return load_id_chunk(fn); }
     /**
      * Load an Identity from an object.  Supported objects are an Identity, a
@@ -140,5 +140,5 @@
      * @return one of the static int return codes.
      */
-    public int loadIDChunk(Object c) {
+    public int load_id_chunk(Object c) {
 	try {
 	    if (c instanceof Identity)
@@ -167,6 +167,6 @@
      * @return one of the static int return codes.
      */
-    public int loadAttributeFile(String fn) { 
-	return loadAttributeChunk(new File(fn));
+    public int load_attribute_file(String fn) { 
+	return load_attribute_chunk(new File(fn));
     }
 
@@ -176,5 +176,5 @@
      * @return one of the static int return codes.
      */
-    public int loadAttributeFile(File fn) { return loadAttributeChunk(fn); }
+    public int load_attribute_file(File fn) { return load_attribute_chunk(fn); }
 
     /**
@@ -186,5 +186,5 @@
      * @return one of the static int return codes.
      */
-    public int loadAttributeChunk(Object c) {
+    public int load_attribute_chunk(Object c) {
 	try {
 	    if (c instanceof Credential)
@@ -436,5 +436,5 @@
      * common name they are disambiguated.  Only one entry for keyid is
      * allowed.
-     * @param i the Identity to add
+     * @param id the Identity to add
      */
     protected void addIdentity(Identity id) { 
@@ -499,5 +499,5 @@
      * alias files into the two maps.  If keys is not null, any key pairs in
      * PEM files are put in there.  If errors is not null, errors reading files
-     * are added indexed by filename.
+     * are added indexed by filename.  This is a jabac extension.
      * @param zf the File to read
      * @param keys a Collection into which to insert unmatched keys
@@ -506,5 +506,5 @@
      *			   returned in the errors parameter.
      */
-    public void readZipFile(File zf, Collection<KeyPair> keys, 
+    public void load_zip_file(File zf, Collection<KeyPair> keys, 
 	    Map<String, Exception> errors) throws IOException {
 	Vector<ZipEntry> derEntries = new Vector<ZipEntry>();
@@ -534,5 +534,5 @@
 			    ids.put(i.getKeyID(), i);
 
-			loadIDChunk(i);
+			load_id_chunk(i);
 		    }
 		    else if (o instanceof KeyPair ) {
@@ -572,15 +572,15 @@
     }
     /**
      * Equivalent to readZipFile(d, null, null).
      * @param d the File to read
      * @throws IOException if the file is unreadable. To see per-entry
      *			    exceptions use a signature with the errors parameter
      */
-    public void readZipFile(File d) 
+    public void load_zip_file(File d) 
 	    throws IOException {
-	readZipFile(d, null, null);
-    }
-    /**
-     * Equivalent to readZipFile(d, null, errors).
+	load_zip_file(d, null, null);
+    }
+    /**
+     * Equivalent to load_zip_file(d, null, errors).
      * @param d the File to read
      * @param errors a Map from entry name to generated exception
@@ -588,10 +588,10 @@
      *			   returned in the errors parameter.
      */
-    public void readZipFile(File d, 
+    public void load_zip_file(File d, 
 	    Map<String, Exception> errors) throws IOException {
-	readZipFile(d, null, errors);
-    }
-    /**
-     * Equivalent to readZipFile(d, keys, null).
+	load_zip_file(d, null, errors);
+    }
+    /**
+     * Equivalent to load_zip_file(d, keys, null).
      * @param d the File to read
      * @param keys a Collection into which to insert unmatched keys
@@ -599,7 +599,7 @@
      *			    exceptions use a signature with the errors parameter
      */
-    public void readZipFile(File d, 
+    public void load_zip_file(File d, 
 	    Collection<KeyPair> keys) throws IOException {
-	readZipFile(d, keys, null);
+	load_zip_file(d, keys, null);
     }
 
@@ -655,5 +655,6 @@
      * alias files into the two maps.  If keys is not null, any key pairs in
      * PEM files are put in there.  If errors is not null, errors reading files
-     * are added indexed by filename.
+     * are added indexed by filename.  This behaves slightly differently from
+     * the load_directory description in the general libabac documentation.
      * @param d the File to read.  If it is a directory its contents are read
      * @param keys a Collection into which to insert unmatched keys
@@ -662,5 +663,5 @@
      *			   returned in the errors parameter.
      */
-    public void readDirectory(File d, Collection<KeyPair> keys, 
+    public void load_directory(File d, Collection<KeyPair> keys, 
 	    Map<String, Exception> errors) {
 	Vector<File> derFiles = new Vector<File>();
@@ -691,5 +692,5 @@
 			    ids.put(i.getKeyID(), i);
 
-			loadIDChunk(i);
+			load_id_chunk(i);
 		    }
 		    else if (o instanceof KeyPair ) {
@@ -729,14 +730,14 @@
     }
     /**
      * Equivalent to readDirectory(d, null, null).
      * @param d the File to read.  If it is a directory its contents are read
      * @throws IOException if the file is unreadable.  To see per-file 
      *                     exceptions use a signature with the errors parameter.
      */
-    public void readDirectory(File d) {
-	readDirectory(d, null, null);
-    }
-    /**
-     * Equivalent to readDirectory(d, null, null).
+    public void load_directory(File d) {
+	load_directory(d, null, null);
+    }
+    /**
+     * Equivalent to load_directory(d, null, null).
      * @param d the File to read.  If it is a directory its contents are read
      * @param errors a Map from entry name to generated exception
@@ -744,9 +745,9 @@
      *			   returned in the errors parameter.
      */
-    public void readDirectory(File d, Map<String, Exception> errors) {
-	readDirectory(d, null, errors);
-    }
-    /**
-     * Equivalent to readDirectory(d, null, null).
+    public void load_directory(File d, Map<String, Exception> errors) {
+	load_directory(d, null, errors);
+    }
+    /**
+     * Equivalent to load_directory(d, null, null).
      * @param d the File to read.  If it is a directory its contents are read
      * @param keys a Collection into which to insert unmatched keys
@@ -754,6 +755,6 @@
      *                     exceptions use a signature with the errors parameter.
      */
-    public void readDirectory(File d, Collection<KeyPair> keys) {
-	readDirectory(d, keys, null);
+    public void load_directory(File d, Collection<KeyPair> keys) {
+	load_directory(d, keys, null);
     }
 
@@ -768,5 +769,5 @@
      * @throws IOException if there is a problem writhing the file.
      */
-    public void writeZipFile(File f, boolean allIDs, boolean withPrivateKeys) 
+    public void write_zip_file(File f, boolean allIDs, boolean withPrivateKeys) 
 	    throws IOException {
 	ZipOutputStream z = new ZipOutputStream(new FileOutputStream(f));
@@ -572,15 +572,15 @@
     }
     /**
-     * Equivalent to readZipFile(d, null, null).
+     * Equivalent to load_zip_file(d, null, null).
      * @param d the File to read
      * @throws IOException if the file is unreadable. To see per-entry
@@ -729,14 +730,14 @@
     }
     /**
-     * Equivalent to readDirectory(d, null, null).
+     * Equivalent to load_directory(d, null, null).
      * @param d the File to read.  If it is a directory its contents are read
      * @throws IOException if the file is unreadable.  To see per-file 
